@@ -1,6 +1,6 @@
 # -*- coding:utf-8 -*-
 
-from ..util import client, formater, list2table, result_cache, it
+from ..util import client, formater, list2table, result_cache
 from terminal import bold, magenta, white, blue, green,red, yellow
 from ..const import CMD
 
@@ -84,7 +84,7 @@ def get(clusterId, descOnly=False, oplog=False):
 
     # mounts
     mounts = result.Configs.Mounts
-    print('%s (Locale: %s , Lock: %s)' % (blue('Mounts:'), mounts.get('Locale'), mounts.get('Lock')))
+    print('%s (Locale: %s , Lock: %s , CacheSupport: %s)' % (blue('Mounts:'), mounts.get('Locale'), mounts.get('Lock'), mounts.get('CacheSupport')))
 
 
     entries = mounts.get('Entries')
@@ -153,11 +153,25 @@ def get(clusterId, descOnly=False, oplog=False):
         v = formater.to_dict(result.Groups[groupName])
         v['Name'] = groupName
         v['VMCount'] = '%s / %s' % (v['ActualVMCount'],v['DesiredVMCount'])
-        ins = it.get_ins_type_map().get(v['InstanceType'])
+        ins = client.get_ins_type_map().get(v['InstanceType'])
         if ins:
             v['InstanceType/cpu/mem'] = '%s, %sCores, %sGB' % (v['InstanceType'], ins['cpu'], ins['memory'])
         else:
             v['InstanceType/cpu/mem'] = v['InstanceType']
+
+        if v.get('Disks'):
+            if v['Disks'].get('SystemDisk'):
+                v['SystemDisk'] = '%s:%sGB' %(v['Disks']['SystemDisk']['Type'], str(v['Disks']['SystemDisk']['Size']) )
+            else:
+                v['SystemDisk'] = ''
+            if v['Disks'].get('DataDisk'):
+                v['DataDisk'] = '%s:%sGB:%s' %( v['Disks']['DataDisk']['Type'] , v['Disks']['DataDisk']['Size'], v['Disks']['DataDisk']['MountPoint'])
+            else:
+                v['DataDisk'] = ''
+        else:
+            v['SystemDisk'] = ''
+            v['DataDisk'] = ''
+
         groups.append(v)
         total_desired_vm_count = total_desired_vm_count + v['DesiredVMCount']
 
@@ -204,7 +218,7 @@ def get(clusterId, descOnly=False, oplog=False):
 
     # print groups
     print('%s' % bold(magenta('Groups:')))
-    list2table.print_table(groups, ['Name','VMCount','InstanceType/cpu/mem', 'ResourceType'])
+    list2table.print_table(groups, ['Name','VMCount','InstanceType/cpu/mem', 'ResourceType','SystemDisk', 'DataDisk'])
 
     # OperationLogs
     if oplog:
