@@ -51,11 +51,12 @@ def update(clusterId, nodes=None, groupName='group', mount=None, image=None, use
 def extend_mount(desc, mount_m):
     for k, v in mount_m.items():
         if k.startswith('oss://') or k.startswith('nas://'):
-            if not desc.get('Configs'): desc['Configs']={'Mounts':{"Entries":[]}}
+            if not desc.get('Configs'):
+                desc['Configs']={'Mounts':{"Entries":[]}}
             desc['Configs']['Mounts']['Entries'].append({
                 "Destination": v,
                 "Source": k,
-                "WriteSupport": True
+                "WriteSupport": k.endswith('/')
             })
 
 def trans_image(image):
