@@ -1,7 +1,7 @@
 
 # -*- coding:utf-8 -*-
 
-from ..util import client,config, formater, oss_client,util
+from ..util import client,config, formater, oss_client,util,dag
 from terminal import green
 import json
 import os
@@ -23,11 +23,13 @@ def submit(cmd=None, job_name=None, description=None, cluster=None, timeout=None
            force=False, auto_release=False, docker=None, pack=None, env=None, read_mount=None, write_mount=None, mount=None,
            file=None, user_data=None, priority=None, image=None,type=None, disk=None, lock=False, locale=None,
            reserve_on_fail=False,
+           no_cache_support=False,
            notification_endpoint=None, notification_topic=None, notification_events=None,
            resource_type=None,
-           nas_access_group=None, nas_file_system=None,
+           nas_access_group=None,
+           nas_file_system=None,
             vpc_cidr_block = None,
-           show_json=False):
+           show_json=False,show_dag=False):
 
     if cmd == None and file == None  or cmd!=None and cmd.startswith('-'):
         print('\n  type "%s sub -h" for more\n' % CMD)
@@ -38,7 +40,7 @@ def submit(cmd=None, job_name=None, description=None, cluster=None, timeout=None
         timeout = int(type)
         type = None
 
-    job_desc = trans_file_to_job_desc(file, not show_json)
+    job_desc = trans_file_to_job_desc(file, not show_json and not show_dag)
 
     opt = {
         'cmd': cmd,
@@ -52,6 +54,7 @@ def submit(cmd=None, job_name=None, description=None, cluster=None, timeout=None
         'force': force,
         'auto_release': auto_release,
         'reserve_on_fail': reserve_on_fail,
+        'no_cache_support': no_cache_support,
         'lock': lock,
         'locale': locale,
 
@@ -83,12 +86,20 @@ def submit(cmd=None, job_name=None, description=None, cluster=None, timeout=None
 
     }
 
-    job_desc = fix_by_opt(job_desc, opt, not show_json)
+    job_desc = fix_by_opt(job_desc, opt, not show_json and show_dag)
 
 
-    deal_with_pack(job_desc, show_json)
+    deal_with_pack(job_desc, show_json or show_dag)
 
-    if show_json:
+    if show_dag:
+        # calc deps
+        deps = util.get_task_deps(job_desc.get('DAG'))
+        matric = dag.sortIndex(deps)
+
+        # dag
+        dag.draw(deps, matric)
+
+    elif show_json:
         print(json.dumps(job_desc, indent=4))
     else:
         result = client.create_job(job_desc)
@@ -238,6 +249,9 @@ def fix_by_opt(desc, opt, check_cluster):
             if opt.get('reserve_on_fail'):
                 task_desc['AutoCluster']['ReserveOnFail'] = opt.get('reserve_on_fail')
 
+            if opt.get('no_cache_support'):
+                task_desc['Mounts']['CacheSupport'] = not opt.get('no_cache_support')
+
             # vpc
             if opt.get('vpc_cidr_block') :
                 if not task_desc['AutoCluster'].get('Configs'):
@@ -267,11 +281,15 @@ def fix_by_opt(desc, opt, check_cluster):
             extend(task_desc['Parameters']['Command']['EnvVars'], trans_docker(opt['docker']))
         if opt.get('env'):
             extend(task_desc['Parameters']['Command']['EnvVars'], trans_env(opt['env']))
+
+        mount_m = get_mount_map(task_desc.get('Mounts'))
         if opt.get('mount'):
-            mount_m = trans_mount(opt['mount'])
-            extend_mount(task_desc, mount_m)
+            extend(mount_m, trans_mount(opt['mount']))
         if opt.get('read_mount'):
-            extend(task_desc['InputMapping'], trans_mount(opt['read_mount']))
+            extend(mount_m, trans_mount(opt['read_mount']))
+        extend_mount(task_desc, mount_m)
+
+
         if opt.get('write_mount'):
             extend(task_desc['OutputMapping'], reverse_kv(trans_mount(opt['write_mount'])))
 
@@ -290,30 +308,34 @@ def fix_by_opt(desc, opt, check_cluster):
 
 
 ########################################
+def get_mount_map(mounts):
+    m = {}
+    if mounts.get('Entries'):
+      for n in mounts['Entries']:
+        m[n['Source']]=n['Destination']
+    return m
 
 def extend_mount(desc, mount_m):
-
+    desc['Mounts']['Entries'] = []
     for k,v in mount_m.items():
-        if k.startswith('oss://'):
-            desc['InputMapping'][k] = v
-            desc['OutputMapping'][v] = k
-        elif k.startswith('nas://'):
+        if k.startswith('oss://') or k.startswith('nas://'):
+
+            # desc['InputMapping'][k] = v
+            # desc['OutputMapping'][v] = k
+        #elif k.startswith('nas://'):
             # desc['AutoCluster']['Configs']['Mounts']['Entries'] = []
             # desc['AutoCluster']['Configs']['Mounts']['Entries'].append({
             #     "Destination": v,
             #     "Source": k,
             #     "WriteSupport": True
             # })
-            desc['Mounts']['Entries'] = []
+
             desc['Mounts']['Entries'].append({
                 "Destination": v,
                 "Source": k,
-                "WriteSupport": True
+                "WriteSupport": k.endswith('/')
             })
 
-
-
-
 def trans_file_to_job_desc(file, check_cluster):
     cf = ConfigParser.ConfigParser()
     # parse file
@@ -396,13 +418,18 @@ def trans_file_to_job_desc(file, check_cluster):
             if cf.has_option(DEFAULT,'docker'):
                 extend(task_desc['Parameters']['Command']['EnvVars'], trans_docker(cf.get(DEFAULT,'docker')))
 
-            if cf.has_option(DEFAULT,'mount'):
-                mount_m = trans_mount(cf.get(DEFAULT,'mount'))
-                extend_mount(task_desc, mount_m)
 
+            mount_m = get_mount_map(task_desc.get('Mounts'))
+
+            if cf.has_option(DEFAULT,'mount'):
+                extend(mount_m , trans_mount(cf.get(DEFAULT,'mount')))
             if cf.has_option(DEFAULT,'read_mount'):
-                r_mount_m = trans_mount(cf.get(DEFAULT,'read_mount'))
-                extend(task_desc['InputMapping'], r_mount_m)
+                extend(mount_m, trans_mount(cf.get(DEFAULT,'read_mount')))
+            extend_mount(task_desc, mount_m)
+
+
+
+
             if cf.has_option(DEFAULT,'write_mount'):
                 w_mount_m = trans_mount(cf.get(DEFAULT,'write_mount'))
                 extend(task_desc['OutputMapping'], reverse_kv(w_mount_m))
@@ -432,6 +459,9 @@ def trans_file_to_job_desc(file, check_cluster):
 
             if cf.has_option(DEFAULT, 'reserve_on_fail'):
                 task_desc['AutoCluster']['ReserveOnFail']=cf.getboolean(DEFAULT, 'reserve_on_fail')
+
+            if cf.has_option(DEFAULT, 'no_cache_support'):
+                task_desc['Mounts']['CacheSupport'] = not cf.getboolean(DEFAULT, 'no_cache_support')
         ###################################
 
 
@@ -526,13 +556,18 @@ def trans_file_to_job_desc(file, check_cluster):
         if cf.has_option(sec,'docker'):
             extend(task_desc['Parameters']['Command']['EnvVars'], trans_docker(cf.get(sec,'docker')))
 
-        if cf.has_option(sec,'mount'):
-            mount_m = trans_mount(cf.get(sec,'mount'))
-            extend_mount(task_desc, mount_m)
 
+        if cf.has_option(sec, 'no_cache_support'):
+            task_desc['Mounts']['CacheSupport'] = not cf.getboolean(sec, 'no_cache_support')
+
+        mount_m = get_mount_map(task_desc.get('Mounts'))
+        if cf.has_option(sec, 'mount'):
+            extend(mount_m,trans_mount(cf.get(sec, 'mount')))
         if cf.has_option(sec,'read_mount'):
-            r_mount_m = trans_mount(cf.get(sec,'read_mount'))
-            extend(task_desc['InputMapping'], r_mount_m)
+            extend(mount_m, trans_mount(cf.get(sec,'read_mount')))
+        extend_mount(task_desc, mount_m)
+
+
         if cf.has_option(sec,'write_mount'):
             w_mount_m = trans_mount(cf.get(sec,'write_mount'))
             extend(task_desc['OutputMapping'], reverse_kv(w_mount_m))
@@ -609,8 +644,10 @@ def trans_env(s):
     arr = s.split(',')
     env = {}
     for item in arr:
-        [k,v]=item.split(':',1)
-        env[k]=v
+        if item.strip() == '':
+            continue
+        kv=item.split(':',1)
+        env[kv[0].strip()] = kv[1].strip() if len(kv) == 2 else ''
     return env
 
 
@@ -632,8 +669,10 @@ def trans_user_data(user_data):
     items = user_data.split(',')
     m = {}
     for item in items:
-        arr = item.split(':',1)
-        m[arr[0]]= arr[1] if len(arr)==2 else ''
+        if item.strip()=='':
+            continue
+        kv = item.split(':',1)
+        m[kv[0].strip()]= kv[1].strip() if len(kv)==2 else ''
     return m
 
 def trans_notification_events(events):
