@@ -49,6 +49,17 @@ class Cli:
         2. %s login cn-qingdao ''' % (COMMAND, CMD, CMD))
         self.program.action(cmd_login)
 
+        # logout
+        cmd_logout = Command('logout',
+                                 description=MSG['logout']['description'],
+                                 func=login.logout)
+        self.program.action(cmd_logout)
+
+
+
+
+
+
         # set config
         cmd_config = Command('config', alias=['me','set'], description=MSG['config']['description'],
                              detail=MSG['config']['detail'],
@@ -255,7 +266,7 @@ class Cli:
         cmd_create_image.option("-d, --description [description]",
                                   MSG['create_image']['option']['description'])
         cmd_create_image.option("--show_json",
-                                  MSG['create_image']['option']['show_json'], visible=IS_GOD)
+                                  MSG['create_image']['option']['show_json'])
         self.program.action(cmd_create_image)
 
 
@@ -310,10 +321,11 @@ class Cli:
                                   MSG['create_cluster']['option']['disk'],
                                   resolve=cluster_create.trans_disk)
 
+
         cmd_create_cluster.option("--resource_type [resource_type]",
                                   MSG['create_cluster']['option']['resource_type'])
 
-        cmd_create_cluster.option("-m, --mount [kv_pairs]", MSG['create_cluster']['option']['mount'],
+        cmd_create_cluster.option("-m, --mount [kv_pairs]", '(%s) %s' % (red(MSG['changed']),MSG['create_cluster']['option']['mount']),
                                   resolve=cluster_create.trans_mount)
         cmd_create_cluster.option("--nas_access_group [nas_access_group]",
                               MSG['create_cluster']['option']['nas_access_group'])
@@ -324,10 +336,15 @@ class Cli:
         cmd_create_cluster.option("--notification_topic [mns_topic]", MSG['create_cluster']['option']['notification_topic'])
         cmd_create_cluster.option("--notification_events [cluster_events]", MSG['create_cluster']['option']['notification_events'],
                               resolve=cluster_create.trans_notification_events)
+        cmd_create_cluster.option("--no_cache_support",
+                                  MSG['create_cluster']['option']['no_cache_support'])
+
         cmd_create_cluster.option("--vpc_cidr_block [vpc_cidr_block]",
                                   MSG['create_cluster']['option']['vpc_cidr_block'])
+        cmd_create_cluster.option("-f, --filePath [filePath]", MSG['create_cluster']['option']['filePath'],
+                                  visible=IS_GOD)
         cmd_create_cluster.option("--show_json",
-                              MSG['create_cluster']['option']['show_json'], visible=IS_GOD)
+                              MSG['create_cluster']['option']['show_json'])
         self.program.action(cmd_create_cluster)
 
         # delete cluster
@@ -369,7 +386,7 @@ class Cli:
         cmd_update_cluster.option("-e, --env [kv_pairs]", MSG['update_cluster']['option']['env'],
                                   resolve=cluster_update.trans_env)
         cmd_update_cluster.option("--show_json",
-                                  MSG['update_cluster']['option']['show_json'], visible=IS_GOD)
+                                  MSG['update_cluster']['option']['show_json'])
         self.program.action(cmd_update_cluster)
 
         ######################
@@ -524,7 +541,7 @@ class Cli:
         cmd_submit_job.option("-e, --env [kv_pairs]", MSG['submit']['option']['env'])
         cmd_submit_job.option("-r, --read_mount [kv_pairs]",  MSG['submit']['option']['read_mount'])
         cmd_submit_job.option("-w, --write_mount [kv_pairs]", MSG['submit']['option']['write_mount'])
-        cmd_submit_job.option("-m, --mount [kv_pairs]", MSG['submit']['option']['mount'])
+        cmd_submit_job.option("-m, --mount [kv_pairs]", '(%s) %s' % (red(MSG['changed']),MSG['submit']['option']['mount']))
 
         cmd_submit_job.option("--nas_access_group [nas_access_group]",
                               MSG['submit']['option']['nas_access_group'])
@@ -547,12 +564,15 @@ class Cli:
         cmd_submit_job.option("--notification_events [job_events]", MSG['submit']['option']['notification_events'],
                               resolve=job_submit.trans_notification_events)
         cmd_submit_job.option("--reserve_on_fail", MSG['submit']['option']['reserve_on_fail'])
+        cmd_submit_job.option("--no_cache_support", MSG['submit']['option']['no_cache_support'])
 
         cmd_submit_job.option("--vpc_cidr_block [vpc_cidr_block]",
                                   MSG['submit']['option']['vpc_cidr_block'])
 
         cmd_submit_job.option("--show_json",
-                              MSG['submit']['option']['show_json'], visible=IS_GOD)
+                              MSG['submit']['option']['show_json'])
+        cmd_submit_job.option("--show_dag",
+                              MSG['submit']['option']['show_dag'])
         self.program.action(cmd_submit_job)
 
 
