@@ -6,9 +6,13 @@ INS_TYPE = 'ecs.s3.large'
 
 def getJSON():
     return {
+        "changed": 'changed',
         "login": {
             "description": "login with Aliyun AccessKey"
         },
+        "logout": {
+            "description": "logout, will delete accessKey and secret in local config file"
+        },
         "config": {
             "description": "read and write configurations",
             "detail": "set configurations, show configurations if no options",
@@ -96,11 +100,11 @@ def getJSON():
                 'env': "optional,set environment variables, format: <k>:<v>[,<k2>:<v2>...]",
                 'user_data': "optional, user data k-v pairs, exp: a:b,c:e",
                 'resource_type': 'optional, default "OnDemand", scope: [OnDemand|Spot]',
-                'disk': """optional, mount system disk and a data disk(optional)Usage: "--disk system:ephemeral:40,data:cloud:50:/home/disk1".
-                                             Default: system:ephemeral:40, mount 40GB ephemeral disk as system disk.
-                                             System disk config format: system:<cloud|ephemeral>:<40-500>,
+                'disk': """optional, mount system disk and a data disk(optional)Usage: "--disk system:default:40,data:cloud:50:/home/disk1".
+                                             Default: system:default:40, mount 40GB default disk as system disk.
+                                             System disk config format: system:<default|cloud|ephemeral...>:<40-500>,
                                              example: system:cloud:40, mount 40GB ephemeral disk as system disk.
-                                             Data disk config format: data:<cloud|ephemeral>:<5-2000>:<mount-point>,
+                                             Data disk config format: data:<default|cloud|ephemeral...>:<5-2000>:<mount-point>,
                                              example: data:cloud:5:/home/disk1, mount a 5GB cloud disk as data disk,
                                              in windows must mount to driver, such as E driver, like: "data:cloud:5:E".
                                              (Attention please: Using ephemeral disk as data disk, the size scope should limit to [5-1024]GB).
@@ -109,14 +113,19 @@ def getJSON():
                 'notification_events': "Events for notification, type '%s e' for more." % CMD,
                 'notification_topic': "Topic name in MNS.",
                 'notification_endpoint': "MNS Endpoint, see in MNS web console.",
-                'mount': """optional,mount a nas path to local file system in read/write mode, kv-pairs, multi-supported,
-                                             format: <nas_path>:<dir_path>[,<nas_path2>:<dir_path2>...],
-                                             example: nas://path/to/mount:/home/admin/dir.
-                                             and it is always using with nas_access_group and nas_file_system""",
+                'mount': """optional,mount nas path to local file system in read/write mode,
+                                             or mount oss path to local file system in read mode.
+                                             format: <nas_path|oss_path>:<dir_path>[,<nas_path2|oss_path2>:<dir_path2>...],
+                                             example: nas://path/to/mount/:/home/admin/dir/.
+                                             and it is always using with nas_access_group and nas_file_system.
+                                             example2: oss://path/to/mount/:/home/admin/dir/,
+                                             and file is also supported: oss://path/to/mount/a.txt:/home/admin/dir/a.txt.""",
                 'nas_access_group': 'NAS access groups',
                 'nas_file_system': 'NAS file system',
+                'no_cache_support': 'optional, cancel the cache for ossmounter',
                 'vpc_cidr_block': 'CIDR, such as: 192.168.0.0/16',
-                'show_json': 'optional, just output cluster json, won\'t create a cluster, default: false'
+                'show_json': 'optional, just output cluster json, won\'t create a cluster, default: false',
+                'filePath': 'submit with a cluster description json file, other options are invalid'
             }
         },
         'delete_cluster': {
@@ -195,27 +204,31 @@ def getJSON():
                 'env': "optional,set environment variables, format: <k>:<v>[,<k2>:<v2>...]",
                 'read_mount': """optional,mount a oss path to local file system in read-only mode, kv-pairs, multi-supported,
                                              format: <oss_path>:<dir_path>[,<oss_path2>:<dir_path2>...],
-                                             example: oss://bucket/key:/home/admin/ossdir """,
+                                             mount folder example: oss://bucket/key/:/home/admin/ossdir/,
+                                             mount file example: oss://bucket/key1:/home/admin/key1 """,
                 'write_mount': """optional,mount a oss path to local file system in writable mode
                                              (files in the mounted folder will be upload to oss_path after the task is finished),
                                              kv-pairs, multi-supported, format: <oss_path>:<dir_path>[,<oss_path2>:<dir_path2>...],
                                              example: oss://bucket/key:/home/admin/ossdir """,
 
-                'mount': """optional,mount a nas path to local file system in read/write mode, kv-pairs, multi-supported,
-                                             format: <nas_path>:<dir_path>[,<nas_path2>:<dir_path2>...],
-                                             example: nas://path/to/mount:/home/admin/dir.
-                                             and it is always using with nas_access_group and nas_file_system""",
+                'mount': """optional,mount nas path to local file system in read/write mode,
+                                             or mount oss path to local file system in read mode.
+                                             format: <nas_path|oss_path>:<dir_path>[,<nas_path2|oss_path2>:<dir_path2>...],
+                                             example: nas://path/to/mount/:/home/admin/dir/.
+                                             and it is always using with nas_access_group and nas_file_system.
+                                             example2: oss://path/to/mount/:/home/admin/dir/,
+                                             and file is also supported: oss://path/to/mount/a.txt:/home/admin/dir/a.txt.""",
                 'docker': """optional,optional, use docker, format: <docker_image_name>@<docker_storage_oss_path>,
                                              example: localhost:5000/myubuntu@oss://bucket/dockers/
                                              or for short: myubuntu@oss://bucket/dockers/ """,
                 'file': """optional,submit job from a config file, if you give options explicitly, options from this file will be override""",
                 'user_data': "optional, user data k-v pairs, exp: a:b,c:e",
                 'disk': """optional, mount system disk and a data disk(optional), only works with AutoCluster.
-                                             Usage: "--disk system:ephemeral:40,data:cloud:50:/home/disk1".
-                                             Default: system:ephemeral:40, mount 40GB ephemeral disk as system disk.
-                                             System disk config format: system:<cloud|ephemeral>:<40-500>,
+                                             Usage: "--disk system:default:40,data:cloud:50:/home/disk1".
+                                             Default: system:default:40, mount 40GB default disk as system disk.
+                                             System disk config format: system:<default|cloud|ephemeral...>:<40-500>,
                                              example: system:cloud:40, mount 40GB ephemeral disk as system disk.
-                                             Data disk config format: data:<cloud|ephemeral>:<5-2000>:<mount-point>,
+                                             Data disk config format: data:<default|cloud|ephemeral...>:<5-2000>:<mount-point>,
                                              example: data:cloud:5:/home/disk1, mount a 5GB cloud disk as data disk,
                                              in windows must mount to driver, such as E driver, like: "data:cloud:5:E".
                                              (Attention please: Using ephemeral disk as data disk, the size scope should limit to [5-1024]GB).
@@ -230,8 +243,10 @@ def getJSON():
                 'nas_file_system': 'NAS file system',
                 'resource_type': 'optional, default "OnDemand", scope: [OnDemand|Spot]',
                 'reserve_on_fail': 'optional, won\'t release auto-cluster when job failed',
+                'no_cache_support': 'optional, cancel the cache for ossmounter',
                 'vpc_cidr_block': 'CIDR, such as: 192.168.0.0/16',
-                'show_json': 'optional,just output job.json, won\'t submit a job, default: false'
+                'show_json': 'optional,just output job.json, won\'t submit a job, default: false',
+                'show_dag': 'optional,just output dag graph, won\'t submit a job, default: false'
             }
         },
         'check': {
@@ -311,7 +326,10 @@ def getJSON():
                 'detail': 'copy oss file or folder. across region support format: <region>#<osspath>, only if the AK is validated'
             },
             'upload': {
-                'description': 'upload file or directory to oss'
+                'description': 'upload file or directory to oss',
+                'option': {
+                    'use_put_object': 'Forced use of the PutObject method to upload (By default, file sizes bigger than 4GB will be uploaded using multi upload)'
+                }
             },
             'download': {
                 'description': 'download file or directory from oss',
