@@ -24,9 +24,13 @@ def getJSON():
 
 def __get_json():
     return {
+        "changed": '有改动',
         "login": {
             "description": "使用阿里云AccessKey登录"
         },
+        "logout": {
+            "description": "退出登录,将删除本地保存的AK配置等"
+        },
         "config": {
             "description": "配置管理",
             "detail": "修改配置, 不带参数则查看配置",
@@ -114,11 +118,11 @@ def __get_json():
                 'resource_type': '可选, 默认 "OnDemand(按需)", 可选范围:[OnDemand|Spot]',
                 'user_data': "可选, 用户数据, k:v 对,多个逗号隔开, 格式: k:v,k2:v2",
                 'disk': """可选, 挂载磁盘, 支持系统盘配置和一块数据盘(可选)的配置,
-                                             使用方法如: "--disk system:ephemeral:40,data:cloud:50:/home/disk1".
-                                             默认只挂载一个系统盘:类型为ephemeral,大小40GB.
-                                             系统盘配置格式: system:<cloud|ephemeral>:<40-500>,
+                                             使用方法如: "--disk system:default:40,data:cloud:50:/home/disk1".
+                                             默认只挂载一个系统盘:类型为 default,大小40GB.
+                                             系统盘配置格式: system:<default|cloud|ephemeral...>:<40-500>,
                                              举例: system:cloud:40, 表示系统盘挂载40GB的云盘.
-                                             数据盘配置格式: data:<cloud|ephemeral>:<5-2000>:<mount-point>,
+                                             数据盘配置格式: data:<default|cloud|ephemeral...>:<5-2000>:<mount-point>,
                                              举例: data:cloud:5:/home/disk1, 表示挂载一个5GB的云盘作为数据盘, window下只能挂载到驱动,如E盘:"data:cloud:5:E".
                                              (注意: 数据盘使用ephemeral的时候,size取值范围限制为:[5-1024]GB).
                                              (运行 '%s d' 可以看到本区域支持的diskType).
@@ -127,13 +131,17 @@ def __get_json():
                 'notification_events': "消息通知的事件,可以用'%s e'查看。" % CMD,
                 'notification_topic': "消息通知的Topic名称,可以在mns创建。",
                 'notification_endpoint': "消息通知的Endpoint, 可以在mns控制台查看。",
-                'mount': """可选,读写模式挂载NAS配置, 格式: <nas_path>:<dir_path>[,<nas_path2>:<dir_path2>...],
-                                             如: nas://path/to/mount:/home/admin/nasdir 表示将NAS路径挂载到本地目录。
-                                             使用NAS挂载还需配置nas_access_group和nas_file_system""",
+                'mount': """可选,读写模式挂载NAS配置或者只读方式挂载OSS, 格式: <nas_path|oss_path>:<dir_path>[,<nas_path2|oss_path2>:<dir_path2>...],
+                                             如: nas://path/to/mount/:/home/admin/nasdir/ 表示将NAS路径挂载到本地目录。
+                                             使用NAS挂载还需配置nas_access_group和nas_file_system。
+                                             如: oss://path/to/mount/:/home/admin/nasdir/ 表示将OSS路径挂载到本地目录,
+                                             也支持直接挂载文件, 如:oss://path/to/mount/a.txt:/home/admin/nasdir/a.txt。""",
                 'nas_access_group': 'NAS 权限组',
                 'nas_file_system': 'NAS 文件系统',
+                'no_cache_support': '可选, 取消OSSMounter缓存',
                 'vpc_cidr_block': 'IP网段,如: 192.168.0.0/16',
-                'show_json': '只显示cluster json不创建'
+                'show_json': '只显示cluster json不创建',
+                'filePath': '通过集群描述json文件提交,其他options将失效'
             }
         },
         'delete_cluster': {
@@ -209,13 +217,16 @@ def __get_json():
                 'auto_release': "可选,当job运行成功(state=='Finished')后自动被释放(删除)掉",
                 'env': "可选,设置环境变量, 格式: <k>:<v>[,<k2>:<v2>...]",
                 'read_mount': """可选,只读模式挂载配置, 格式: <oss_path>:<dir_path>[,<oss_path2>:<dir_path2>...],
-                                             如: oss://bucket/key:/home/admin/ossdir 表示将oss的路径挂载到本地目录""",
+                                             挂载目录例子: oss://bucket/key/:/home/admin/ossdir/ 表示将oss的路径挂载为本地目录,
+                                             挂载文件例子: oss://bucket/key1:/home/admin/key1 表示将oss的文件挂载为本地文件""",
                 'write_mount': """可选,可写模式挂载配置(任务结束后写到本地目录的文件会被上传到相应的oss_path下),
                                              格式: <oss_path>:<dir_path>[,<oss_path2>:<dir_path2>...],
                                              如: oss://bucket/key:/home/admin/ossdir 表示将oss的路径挂载到本地目录""",
-                'mount': """可选,读写模式挂载NAS配置, 格式: <nas_path>:<dir_path>[,<nas_path2>:<dir_path2>...],
-                                             如: nas://path/to/mount:/home/admin/nasdir 表示将NAS路径挂载到本地目录。
-                                             使用NAS挂载还需配置nas_access_group和nas_file_system""",
+                'mount': """可选,读写模式挂载NAS配置或者只读方式挂载OSS, 格式: <nas_path|oss_path>:<dir_path>[,<nas_path2|oss_path2>:<dir_path2>...],
+                                             如: nas://path/to/mount/:/home/admin/nasdir/ 表示将NAS路径挂载到本地目录。
+                                             使用NAS挂载还需配置nas_access_group和nas_file_system。
+                                             如: oss://path/to/mount/:/home/admin/nasdir/ 表示将OSS路径挂载到本地目录,
+                                             也支持直接挂载文件, 如:oss://path/to/mount/a.txt:/home/admin/nasdir/a.txt。""",
                 'docker': """可选, 使用docker镜像运行, 格式: <image_name>@<storage_oss_path>,
                                              如: localhost:5000/myubuntu@oss://bucket/dockers/
                                              或者: myubuntu@oss://bucket/dockers/""",
@@ -223,11 +234,11 @@ def __get_json():
                 'user_data': "可选, 用户数据, k:v 对,多个逗号隔开, 格式: k:v,k2:v2",
                 'disk': """可选,挂载磁盘, 只在使用AutoCluster时有效, 支持系统盘配置和一块数据盘(可选)的配置,
 
-                                             使用方法如: "--disk system:ephemeral:40,data:cloud:50:/home/disk1".
-                                             默认只挂载一个系统盘:类型为ephemeral,大小40GB.
-                                             系统盘配置格式: system:<cloud|ephemeral>:<40-500>,
+                                             使用方法如: "--disk system:default:40,data:cloud:50:/home/disk1".
+                                             默认只挂载一个系统盘:类型为default,由服务端自动指定, 大小40GB.
+                                             系统盘配置格式: system:<default|cloud|ephemeral...>:<40-500>,
                                              举例: system:cloud:40, 表示系统盘挂载40GB的云盘.
-                                             数据盘配置格式: data:<cloud|ephemeral>:<5-2000>:<mount-point>,
+                                             数据盘配置格式: data:<default|cloud|ephemeral...>:<5-2000>:<mount-point>,
                                              举例: data:cloud:5:/home/disk1, 表示挂载一个5GB的云盘作为数据盘, window下只能挂载到驱动,如E盘:"data:cloud:5:E".
                                              (注意: 数据盘使用ephemeral的时候,size取值范围限制为:[5-1024]GB).
                                              (运行 '%s d' 可以看到本区域支持的diskType).
@@ -241,8 +252,10 @@ def __get_json():
                 'nas_file_system': 'NAS 文件系统',
                 'resource_type': '可选, 默认 "OnDemand(按需)", 可选范围:[OnDemand|Spot]',
                 'reserve_on_fail': '可选, 作业失败不会释放autoCluster, 便于调查问题',
+                'no_cache_support': '可选, 取消OSSMounter缓存',
                 'vpc_cidr_block': 'IP网段,如: 192.168.0.0/16',
-                'show_json': '只显示json不提交作业'
+                'show_json': '只显示json不提交作业',
+                'show_dag': '只显示DAG图不提交作业'
             }
         },
         'check': {
@@ -322,7 +335,10 @@ def __get_json():
                 'detail': '复制OSS文件或目录, 可以跨域复制, 使用osspath格式: <region>#<osspath>'
             },
             'upload': {
-                'description': '上传文件或目录到OSS'
+                'description': '上传文件或目录到OSS',
+                'option': {
+                    'use_put_object': '强制使用 PutObject 方法上传 (默认情况下超过4GB将使用multi upload方式上传)'
+                }
             },
             'download': {
                 'description': '下载文件或目录',
