@@ -1,7 +1,9 @@
 from batchcompute import Client
-
+from ..const import IT_MAP,VERSION
 from .config import getConfigs,COMMON
 from batchcompute.utils import set_log_level
+from . import formater,it_config
+import platform
 
 set_log_level("ERROR")
 
@@ -12,12 +14,23 @@ def _get_endpoint(region):
 
 
 def _get_client(opt=None):
-    opt = opt or getConfigs(COMMON, ['region', 'accesskeyid','accesskeysecret'])
+    opt = opt or getConfigs(COMMON, ['region', 'accesskeyid','accesskeysecret','version','ssl'])
     if not opt or not opt.get('accesskeyid'):
         raise Exception('You need to login first')
 
-    return Client(_get_endpoint(opt.get('region')),
-        opt.get('accesskeyid'), opt.get('accesskeysecret'))
+    headers = {
+       'x-client-name': 'batchcompute-cli',
+       'x-client-version':VERSION,
+       'User-Agent':'Platform/%s Python/%s batchcompute-cli/%s' % (platform.platform(), platform.python_version(), VERSION)
+    }
+
+    c = Client(_get_endpoint(opt.get('region')),
+        opt.get('accesskeyid'), opt.get('accesskeysecret'),security_conn=not opt.get('ssl'),
+        **headers)
+
+    if opt.get('version'):
+        c.version = opt.get('version')
+    return c
 
 def check_client(opt):
     client = _get_client(opt)
@@ -56,7 +69,9 @@ def change_cluster_vmcount(cluster_id, groupName, vmCount):
     client = _get_client()
     return client.change_cluster_desired_vm_count(cluster_id, **{groupName: int(vmCount)})
 
-
+def update_cluster(cluster_id, clsuterDesc):
+    client = _get_client()
+    return client.modify_cluster(cluster_id, clsuterDesc)
 
 
 def list_jobs():
@@ -155,6 +170,75 @@ def create_job(jobDesc):
     client = _get_client()
     return client.create_job(jobDesc)
 
+def list_images():
+    client = _get_client()
+
+    sysArr = __list_images(client,'',100,type_='System')
+    arr = __list_images(client)
+    return {'Items': sysArr + arr,'Marker':''}
+
+def __list_images(client, marker='', maxItemCount=100, type_=''):
+    t = []
+    result = client.list_images(marker, maxItemCount, type_)
+    if result.Items:
+        t = t + __items2list(result.Items)
+
+    if result.NextMarker and result.NextMarker!='':
+        arr = __list_images(client,result.NextMarker,maxItemCount,type_)
+        t = t + arr
+    return t
+
+
+def get_image(image_id):
+    client = _get_client()
+    return client.get_image(image_id)
+
+def delete_image(image_id):
+    client = _get_client()
+    return client.delete_image(image_id)
+
+def create_image(imageDesc):
+    client = _get_client()
+    return client.create_image(imageDesc)
+
+def get_quotas():
+    client = _get_client()
+    return client.get_quotas()
+
+def list_instance_types():
+    quotas = get_quotas()
+    arr = quotas.AvailableClusterInstanceType
+
+    itmap = it_config.get()
+    t=[]
+    for n in arr:
+        t.append( itmap[n] if itmap.get(n) else {'name':str(n),'cpu': -1,'memory':-1} )
+    t = formater.order_by(t, ['cpu','memory'],False)
+
+    return t
+
+def list_spot_instance_types():
+    quotas = get_quotas()
+    arr = quotas.AvailableSpotInstanceType
+
+    itmap = it_config.get()
+    t = []
+    for n in arr:
+        t.append(itmap[n] if itmap.get(n) else {'name': str(n), 'cpu': -1, 'memory': -1})
+    t = formater.order_by(t, ['cpu', 'memory'], False)
+    return t
+
+
+def get_ins_type_map():
+    arr = list_instance_types() or []
+    arr2 = list_spot_instance_types() or []
+    m = {}
+    for item in arr:
+        m[item['name']] = item
+    for item in arr2:
+        m[item['name']] = item
+    return m
+
 
 def __items2list(items):
     t=[]
